        function getT(rr,cc){
       if(rr==4 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==4 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <strong>control</strong><br>0,1,2,4,5,7,9,10,12,16,19,23,24,28,29,31,34,36,39,44,47,49';}
       if(rr==4 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 20 <br>3,6,8,13,15,20,22,27,30,32,33,35,38,40,41,42,43,45,48,50';}
       if(rr==4 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 9 <br>11,14,17,18,21,25,26,37,46';}
       if(rr==23 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==23 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <strong>control</strong><br>0,1,2,4,5,7,9,10,12,16,19,23,24,28,29,31,34,36,39,44,47,49';}
       if(rr==23 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 20 <br>3,6,8,13,15,20,22,27,30,32,33,35,38,40,41,42,43,45,48,50';}
       if(rr==23 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 9 <br>11,14,17,18,21,25,26,37,46';}
       if(rr==25 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==25 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <strong>control</strong><br>0,1,2,4,5,7,9,10,12,16,19,23,24,28,29,31,34,36,39,44,47,49';}
       if(rr==25 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 20 <br>3,6,8,13,15,20,22,27,30,32,33,35,38,40,41,42,43,45,48,50';}
       if(rr==25 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 2 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 9 <br>11,14,17,18,21,25,26,37,46';}
       if(rr==26 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==26 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <strong>control</strong><br>0,1,2,4,5,7,9,10,12,16,19,23,24,28,29,31,34,36,39,44,47,49';}
       if(rr==26 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 20 <br>3,6,8,13,15,20,22,27,30,32,33,35,38,40,41,42,43,45,48,50';}
       if(rr==26 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 5 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 9 <br>11,14,17,18,21,25,26,37,46';}
       if(rr==27 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==27 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <strong>control</strong><br>0,1,2,4,5,7,9,10,12,16,19,23,24,28,29,31,34,36,39,44,47,49';}
       if(rr==27 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 20 <br>3,6,8,13,15,20,22,27,30,32,33,35,38,40,41,42,43,45,48,50';}
       if(rr==27 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 10 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 9 <br>11,14,17,18,21,25,26,37,46';}
       if(rr==28 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br><strong>control +<br>EPS</strong>';}
       if(rr==28 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>1</strong> representante: <strong>16</strong> miembros: 22 <strong>control</strong><br>0,1,2,4,5,7,9,10,12,16,19,23,24,28,29,31,34,36,39,44,47,49';}
       if(rr==28 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>2</strong> representante: <strong>6</strong> miembros: 20 <br>3,6,8,13,15,20,22,27,30,32,33,35,38,40,41,42,43,45,48,50';}
       if(rr==28 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 20 mm de agua equivalente</strong><br><br><strong>20260515 a 00</strong> UTC HH+156 (rango:144-168)<br>grupo: <strong>3</strong> representante: <strong>11</strong> miembros: 9 <br>11,14,17,18,21,25,26,37,46';}
}
